> ![MikroE](http://www.mikroe.com/img/designs/beta/logo_small.png)
> #R Meter Click#
> ##By [MikroElektronika](http://www.mikroe.com)
---

## Installation
Use the package manager to install the library for your architecture.

###Example on PIC32
```
#include <stdint.h>
#include "r_meter.h"

//sbits
sbit S1             at RD0_bit;
sbit S1_DIR         at TRISD0_bit;
sbit S2             at RE8_bit;
sbit S2_DIR         at TRISE8_bit;
sbit S3             at RC1_bit;
sbit S3_DIR         at TRISC1_bit;
sbit R_METER_CS     at RC2_bit;
sbit R_METER_CS_DIR at TRISC2_bit;

void system_setup( void )
{
    // GPIOs
    S1_DIR = 0;
    S2_DIR = 0;
    S3_DIR = 0;
    R_METER_CS_DIR = 0;

    //UART
    UART2_Init(9600);                      // Initialize UART module at 9600 bps
    Delay_ms(100);                         // Wait for UART module to stabilize
    UART2_Write_Text( "Starting\r\n" );
    //ADC
    ADC1_Init();
    Delay_ms(200);
    UART2_Write_Text( "UART Initialized\r\n" );
    // SPI
    SPI3_Init_Advanced( _SPI_MASTER, _SPI_8_BIT, 1, _SPI_SS_DISABLE,
                    _SPI_DATA_SAMPLE_END, _SPI_CLK_IDLE_LOW,
                    _SPI_IDLE_2_ACTIVE );
    Delay_ms( 200 );
    UART2_Write_Text( "SPI Initialized\r\n" );

    r_meter_init();
    UART2_Write_Text( "R Meter Initialized\r\n" );
}

```

```
void main()
{
    //Local Declarations
    char txt[20] = { 0 };
    float ohms_var = 0;
    
    //Setup
    system_setup();

    while (1)
    {
        ohms_var = r_meter_get_ohms();
        if( ohms_var == 0 )
            UART2_Write_Text( "Over Range\r\n" );
        else
        {
            FloatToStr( ohms_var, txt );
            UART2_Write_Text( "OHMS: " );
            UART2_Write_Text( txt );
            UART2_Write_Text( "\r\n" );
        }
        delay_ms(250);
    }
}

```

